using System;
using System.Net.Http;
using FluentAssertions;
using NUnit.Framework;

namespace E2ETests.Sender;

[TestFixture]
public class SenderTestUnhappyPath : SenderTestBase {
    [Test]
    public void WithDestination_UnknownUUID_ShouldThrowAggregateWithInnerHttpRequestException() {
        Assert.Throws<AggregateException>(() => {
            _fluentSender.WithDestination(Guid.Empty.ToString());
        }).InnerExceptions.Should().ContainItemsAssignableTo<HttpRequestException>();
    }


    [Test]
    public void WithDestination_CompletelyWrong_ShouldThrowArgumentException() {
        Assert.Throws<ArgumentException>(() => {
            _fluentSender.WithDestination("This is very wrong");
        }).Message.Should().Be("The destination must be a valid GUID");
    }

    [Test]
    public void WithData_DataIsInvalidJson_ShouldThrowArgumentException() {
        Assert.Throws<ArgumentException>(() => { _fluentSender.WithData("This is very wrong"); })
            .Message.Should().Be("The data must be valid JSON string");
    }
}
